@@ -293,19 +293,28 @@ class BuildApiMixin(object):
         # Send the full auth configuration (if any exists), since the build
         # could use any (or all) of the registries.
         if self._auth_configs:
+            auth_cfgs = self._auth_configs
             auth_data = {}
-            if self._auth_configs.get('credsStore'):
+            if auth_cfgs.get('credsStore'):
                 # Using a credentials store, we need to retrieve the
                 # credentials for each registry listed in the config.json file
                 # Matches CLI behavior: https://github.com/docker/docker/blob/
                 # 67b85f9d26f1b0b2b240f2d794748fac0f45243c/cliconfig/
                 # credentials/native_store.go#L68-L83
-                for registry in self._auth_configs.get('auths', {}).keys():
+                for registry in auth_cfgs.get('auths', {}).keys():
                     auth_data[registry] = auth.resolve_authconfig(
-                        self._auth_configs, registry
+                        auth_cfgs, registry,
+                        credstore_env=self.credstore_env,
                     )
             else:
-                auth_data = self._auth_configs.get('auths', {}).copy()
+                for registry in auth_cfgs.get('credHelpers', {}).keys():
+                    auth_data[registry] = auth.resolve_authconfig(
+                        auth_cfgs, registry,
+                        credstore_env=self.credstore_env
+                    )
+                for registry, creds in auth_cfgs.get('auths', {}).items():
+                    if registry not in auth_data:
+                        auth_data[registry] = creds
                 # See https://github.com/docker/docker-py/issues/1683
                 if auth.INDEX_NAME in auth_data:
                     auth_data[auth.INDEX_URL] = auth_data[auth.INDEX_NAME]
@@ -330,7 +339,14 @@ def process_dockerfile(dockerfile, path):
     abs_dockerfile = dockerfile
     if not os.path.isabs(dockerfile):
         abs_dockerfile = os.path.join(path, dockerfile)
-
+        if constants.IS_WINDOWS_PLATFORM and path.startswith(
+                constants.WINDOWS_LONGPATH_PREFIX):
+            abs_dockerfile = '{}{}'.format(
+                constants.WINDOWS_LONGPATH_PREFIX,
+                os.path.normpath(
+                    abs_dockerfile[len(constants.WINDOWS_LONGPATH_PREFIX):]
+                )
+            )
     if (os.path.splitdrive(path)[0] != os.path.splitdrive(abs_dockerfile)[0] or
             os.path.relpath(abs_dockerfile, path).startswith('..')):
         # Dockerfile not in context - read data to insert into tar later
@@ -341,4 +357,9 @@ def process_dockerfile(dockerfile, path):
             )
 
     # Dockerfile is inside the context - return path relative to context root
-    return (os.path.relpath(abs_dockerfile, path), None)
+    if dockerfile == abs_dockerfile:
+        # Only calculate relpath if necessary to avoid errors
+        # on Windows client -> Linux Docker
+        # see https://github.com/docker/compose/issues/5969
+        dockerfile = os.path.relpath(abs_dockerfile, path)
+    return (dockerfile, None)
