@@ -5,7 +5,7 @@ from .healthcheck import Healthcheck
 from .networks import EndpointConfig, IPAMConfig, IPAMPool, NetworkingConfig
 from .services import (
     ConfigReference, ContainerSpec, DNSConfig, DriverConfig, EndpointSpec,
-    Mount, Placement, Privileges, Resources, RestartPolicy, SecretReference,
-    ServiceMode, TaskTemplate, UpdateConfig
+    Mount, Placement, Privileges, Resources, RestartPolicy, RollbackConfig,
+    SecretReference, ServiceMode, TaskTemplate, UpdateConfig
 )
 from .swarm import SwarmSpec, SwarmExternalCA
